| fc_draw | R Documentation |
This function allows to draw the flowchart from a fc object.
fc_draw(
object,
big.mark = "",
box_corners = "round",
arrow_angle = 30,
arrow_length = grid::unit(0.1, "inches"),
arrow_ends = "last",
arrow_type = "closed",
arrow_color = "black",
arrow_fill = "black",
arrow_lwd = 1,
arrow_lineend = "round",
arrow_linejoin = "round",
title = NULL,
title_x = 0.5,
title_y = 0.9,
title_color = "black",
title_fs = 15,
title_fface = 2,
title_ffamily = NULL,
canvas_bg = "white"
)
object |
fc object that we want to draw. |
big.mark |
character. Used to specify the thousands separator for patient count values. Defaults is no separator ( |
box_corners |
Indicator of whether to draw boxes with round ( |
arrow_angle |
The angle of the arrow head in degrees, as in |
arrow_length |
A unit specifying the length of the arrow head (from tip to base), as in |
arrow_ends |
One of |
arrow_type |
One of |
arrow_color |
Color of the arrows. Default is |
arrow_fill |
Color for filling the arrow head. Default is |
arrow_lwd |
Line width of the arrows. Default is 1. See the |
arrow_lineend |
Line end style for arrows. One of |
arrow_linejoin |
Line join style for arrow heads (i.e., shape of arrow head corners). One of |
title |
The title of the flowchart. Default is |
title_x |
x coordinate for the title. Default is 0.5. |
title_y |
y coordinate for the title. Default is 0.9. |
title_color |
Color of the title. It is |
title_fs |
Font size of the title. It is 15 by default. See the |
title_fface |
Font face of the title. It is 2 by default. See the |
title_ffamily |
Changes the font family of the title. Default is |
canvas_bg |
Background color for the entire canvas (the area behind the flowchart boxes). Default is |
Invisibly returns the same object that has been given to the function, with the given arguments to draw the flowchart stored in the attributes.
safo |>
as_fc(label = "Patients assessed for eligibility") |>
fc_filter(!is.na(group), label = "Randomized", show_exc = TRUE) |>
fc_split(group) |>
fc_filter(itt == "Yes", label = "Included in ITT") |>
fc_filter(pp == "Yes", label = "Included in PP") |>
fc_draw()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.