fc_view: fc_view

View source: R/fc_view.R

fc_viewR Documentation

fc_view

Description

This function allows you to return either the data stored in ⁠$data⁠ or the flowchart information stored in ⁠$fc⁠.

Usage

fc_view(object, what)

Arguments

object

fc object that we want to access.

what

Choose "data" to return the data associated to the flowchart stored in ⁠$data⁠ or "fc" to return the flowchart information stored in ⁠$fc⁠.

Value

Returns a tibble. Either ⁠$data⁠ or ⁠$fc⁠.

Examples

#Return the data associated to the flowchart
safo |>
 as_fc(label = "Patients assessed for eligibility") |>
 fc_filter(!is.na(group), label = "Randomized", show_exc = TRUE) |>
 fc_view("data")

#Return the flowchart information
safo |>
 as_fc(label = "Patients assessed for eligibility") |>
 fc_filter(!is.na(group), label = "Randomized", show_exc = TRUE) |>
 fc_view("fc")


flowchart documentation built on Nov. 26, 2025, 5:08 p.m.