update_x: update_x

View source: R/utils.R

update_xR Documentation

update_x

Description

Function to update the horizontal position of the previuosly created flow charts, to merge two flowcharts used in fc_merge().

Usage

update_x(x, i, n)

Arguments

x

old horizontal position of the boxes

i

position of the flowchart within the list of flowcharts.

n

number of total flowcharts to merge


flowchart documentation built on Nov. 26, 2025, 5:08 p.m.