update_y_stack: update_y_stack

update_y_stackR Documentation

update_y_stack

Description

Function to update the vertical position of the previuosly created flowcharts, to stack the two flowcharts with fc_stack().

Usage

update_y_stack(y, x, type, i, n)

Arguments

y

old vertical position of the boxes

x

old horizontal position of the boxes

type

type of the boxes

i

position of the flowchart within the list of flowcharts.

n

number of total flowcharts to merge


flowchart documentation built on Nov. 26, 2025, 5:08 p.m.