update_y_stack_unite: update_y_stack_unite

update_y_stack_uniteR Documentation

update_y_stack_unite

Description

Function to update the vertical position of the previuosly created flowcharts, to stack the two flowcharts with fc_stack(), when unite is TRUE.

Usage

update_y_stack_unite(y, x, type)

Arguments

y

old vertical position of the boxes

x

old horizontal position of the boxes

type

type of the boxes


flowchart documentation built on Nov. 26, 2025, 5:08 p.m.