| format_percentage | R Documentation |
rounds percentage values while allowing the option to trim_trailing_zeros
format_percentage(value, round_digits, trim_trailing_zeros)
value |
numeric; percentage value to be rounded |
round_digits |
integer; number of digits past the decimal to round to |
trim_trailing_zeros |
logical; trim trailing zeros or not in returned value. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.