quiet_prettyNum: quiet_prettyNum

quiet_prettyNumR Documentation

quiet_prettyNum

Description

Wrapper for prettyNum() that suppresses the original warning message if user big.mark equal to the character defined in the R environment OutDec option.

Usage

quiet_prettyNum(x, big.mark)

Arguments

x

an atomic numerical or character object, possibly complex, typically a vector of real numbers.

big.mark

character. Used to specify the thousands separator for patient count values.


flowchart documentation built on Nov. 26, 2025, 5:08 p.m.