| update_numbers | R Documentation |
Updates values of n or N referenced in the text column when user specifies big.mark argument in fc_draw.
update_numbers(object, big.mark = "")
object |
fc object that we want to draw. |
big.mark |
character. Used to specify the thousands separator for patient count values. Defaults is no separator ( |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.